@@ -111,6 +111,8 @@ class TestQueries(yaql.tests.TestCase):
     def test_sum(self):
         data = range(4)
         self.assertEqual(6, self.eval('$.sum()', data=data))
+        self.assertEqual(106, self.eval('$.sum(100)', data=data))
+        self.assertEqual(100, self.eval('[].sum(100)'))
 
     def test_memorize(self):
         generator_func = lambda: (i for i in range(3))
@@ -133,7 +135,7 @@ class TestQueries(yaql.tests.TestCase):
     def test_single(self):
         self.assertEqual(2, self.eval('list(2).single()'))
         self.assertRaises(StopIteration, self.eval, 'list().single()')
-        self.assertRaises(ValueError, self.eval, 'list(1, 2).single()')
+        self.assertRaises(StopIteration, self.eval, 'list(1, 2).single()')
 
     def test_last(self):
         self.assertEqual(3, self.eval('list(2, 3).last()'))
@@ -210,18 +212,18 @@ class TestQueries(yaql.tests.TestCase):
         self.assertItemsEqual(
             [[1, 'ac'], [2, 'be'], [3, 'd']],
             self.eval('$.items().orderBy($[0]).'
-                      'groupBy($[1], $[0], [$[0], $[1].sum()])', data=data))
+                      'groupBy($[1], $[0], $.sum())', data=data))
 
         self.assertItemsEqual(
             [[1, ['a', 1, 'c', 1]], [2, ['b', 2, 'e', 2]], [3, ['d', 3]]],
             self.eval('$.items().orderBy($[0]).'
-                      'groupBy($[1],,  [$[0], $[1].sum()])',
+                      'groupBy($[1],,  $.sum())',
                       data=data))
 
         self.assertItemsEqual(
             [[1, ['a', 1, 'c', 1]], [2, ['b', 2, 'e', 2]], [3, ['d', 3]]],
             self.eval('$.items().orderBy($[0]).'
-                      'groupBy($[1], aggregator =>  [$[0], $[1].sum()])',
+                      'groupBy($[1], aggregator => $.sum())',
                       data=data))
 
     def test_join(self):
@@ -304,7 +306,7 @@ class TestQueries(yaql.tests.TestCase):
             [[1, 2], [3, 4], [5]],
             self.eval('[1,2,3,4,5].slice(2)'))
 
-    def test_split(self):
+    def test_split_where(self):
         self.assertEqual(
             [[], [2, 3], [5]],
             self.eval('range(1, 6).splitWhere($ mod 3 = 1)'))
@@ -464,6 +466,26 @@ class TestQueries(yaql.tests.TestCase):
                 '$.d1.mergeWith($.d2,, min($1, $2))',
                 data={'d1': dict1, 'd2': dict2}))
 
+    def test_is_iterable(self):
+        self.assertEqual(
+            True,
+            self.eval('isIterable([])'))
+        self.assertEqual(
+            True,
+            self.eval('isIterable([1,2])'))
+        self.assertEqual(
+            True,
+            self.eval('isIterable(set(1,2))'))
+        self.assertEqual(
+            False,
+            self.eval('isIterable(1)'))
+        self.assertEqual(
+            False,
+            self.eval('isIterable("foo")'))
+        self.assertEqual(
+            False,
+            self.eval('isIterable({"a" => 1})'))
+
     def test_infinite_collections(self):
         self.assertRaises(
             exceptions.CollectionTooLargeException,
